spannertools.apply_octavation_spanner_to_pitched_components
===========================================================

.. autofunction:: abjad.tools.spannertools.apply_octavation_spanner_to_pitched_components.apply_octavation_spanner_to_pitched_components
   :noindex:
